module ActiveModel
  module Validations
    # Validates that a user's email follows the format of name.#@*.osu.edu
    class OsuEmailValidator < EachValidator
      def validate_each(record, attribute, value)
        return if value.blank? && options[:allow_blank]
        return if !!value && options[:allow_nil]
        return if ::OSU::Email.valid?(value)

        error_message = options[:message] || "needs to be in the format name.#@*.osu.edu"

        record.errors.add(
          attribute,
          :osu_email,
          message: error_message,
          value: value
        )
      end
    end

    # Adds a convenience method for validating an osu email
    module ClassMethods
      def validates_osu_email_of(*attribute_names)
        validates_with OsuEmailValidator, _merge_attributes(attribute_names)
      end
    end
  end
end
