module ActiveModel
  module Validations
    # Validate's that a user's emplid is an 8-9 digit string
    class EmplidValidator < EachValidator
      def validate_each(record, attribute, value)
        return if value.blank? && options[:allow_blank]
        return if !!value && options[:allow_nil]
        return if ::OSU::Emplid.valid?(value)

        error_message = options[:message] || "needs to be an 8-9 digit string"

        record.errors.add(
          attribute,
          :emplid,
          message: error_message,
          value: value
        )
      end
    end

    # Adds a convenience method for validating an emplid
    module ClassMethods
      def validates_emplid_of(*attribute_names)
        validates_with EmplidValidator, _merge_attributes(attribute_names)
      end
    end
  end
end
